==> duiba-service-api-1.1-20160516.055116-62-sources.jar: cn/com/duiba/service/domain/dataobject/DeveloperDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

public class DeveloperDO extends BaseDO {
	private static final long serialVersionUID = 42212321L;
	
	public static final int BANNER = 1;
	public static final int SWITCH_POWERED_BY = 2;	// 位运算第二位，表示是否在该开发者手机端展示powered by
	
	private Long id;
	private String email;
	private String password;
	private String name;
	private String company;
	private String phone;
	private Boolean verify;
	private Boolean enable;
	private Integer remindMoney;
	private Date lastRemindTime;
	private Integer developerSwitch;
	
	private Date gmtCreate;
	private Date gmtModified;
	
	private transient AppDO fristApp;//第一个创建的App
	
	public AppDO getFristApp() {
		return fristApp;
	}

	public void setFristApp(AppDO fristApp) {
		this.fristApp = fristApp;
	}

	public DeveloperDO() {
	}

	public DeveloperDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public DeveloperDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;
			verify = false;
			enable = true;
			gmtCreate = new Date();
			gmtModified = gmtCreate;
			developerSwitch = 0;
		}
	}
	
	public boolean getSwitch(Integer type){
		int v=1<<type;
		int ret= developerSwitch & v;
		return ret!=0;
	}
	
	public void disableSwitch(Integer type) {
		int v=1<<type;
		v=~v;
		developerSwitch = developerSwitch & v;
	}
	
	public void enableSwitch(Integer type) {
		int v=1<<type;
		developerSwitch = developerSwitch | v;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getCompany() {
		return company;
	}

	public void setCompany(String company) {
		this.company = company;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public Boolean getVerify() {
		return verify;
	}

	public void setVerify(Boolean verify) {
		this.verify = verify;
	}

	public Boolean getEnable() {
		return enable;
	}

	public void setEnable(Boolean enable) {
		this.enable = enable;
	}

	public Integer getRemindMoney() {
		return remindMoney;
	}

	public void setRemindMoney(Integer remindMoney) {
		this.remindMoney = remindMoney;
	}

	public Date getLastRemindTime() {
		return lastRemindTime;
	}

	public void setLastRemindTime(Date lastRemindTime) {
		this.lastRemindTime = lastRemindTime;
	}
	
	public Integer getDeveloperSwitch() {
		return developerSwitch;
	}

	public void setDeveloperSwitch(Integer developerSwitch) {
		this.developerSwitch = developerSwitch;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	
	@Override
	public int hashCode() {
		return id.hashCode() * 37 + email.hashCode() * 17;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof DeveloperDO) {
			DeveloperDO developer = (DeveloperDO) obj;
			return (developer.id.equals(id) && developer.email.equals(email));
		}
		return super.equals(obj);
	}
}

==> duiba-service-api-1.7.7.4-sources.jar: cn/com/duiba/service/domain/dataobject/DeveloperDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

public class DeveloperDO extends BaseDO {
	private static final long serialVersionUID = 42212321L;
	
	public static final int BANNER = 1;
	public static final int SWITCH_POWERED_BY = 2;	// 位运算第二位，表示是否在该开发者手机端展示powered by
	
	private Long id;
	private String email;
	private String password;
	private String name;
	private String company;
	private String phone;
	private Boolean verify;
	private Boolean enable;
	private Integer remindMoney;
	private Date lastRemindTime;
	private Integer developerSwitch;
	
	private String json;//json扩展字段,数据库当前长度:255,当前最大使用量90
	
	private Date gmtCreate;
	private Date gmtModified;
	
	private AppDO fristApp;//第一个创建的App
	
	public AppDO getFristApp() {
		return fristApp;
	}

	public void setFristApp(AppDO fristApp) {
		this.fristApp = fristApp;
	}

	public DeveloperDO() {
	}

	public DeveloperDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public DeveloperDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;
			verify = false;
			enable = true;
			gmtCreate = new Date();
			gmtModified = gmtCreate;
			developerSwitch = 0;
		}
	}
	
	public boolean getSwitch(Integer type){
		int v=1<<type;
		int ret= developerSwitch & v;
		return ret!=0;
	}
	
	public void disableSwitch(Integer type) {
		int v=1<<type;
		v=~v;
		developerSwitch = developerSwitch & v;
	}
	
	public void enableSwitch(Integer type) {
		int v=1<<type;
		developerSwitch = developerSwitch | v;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getCompany() {
		return company;
	}

	public void setCompany(String company) {
		this.company = company;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public Boolean getVerify() {
		return verify;
	}

	public void setVerify(Boolean verify) {
		this.verify = verify;
	}

	public Boolean getEnable() {
		return enable;
	}

	public void setEnable(Boolean enable) {
		this.enable = enable;
	}

	public Integer getRemindMoney() {
		return remindMoney;
	}

	public void setRemindMoney(Integer remindMoney) {
		this.remindMoney = remindMoney;
	}

	public Date getLastRemindTime() {
		return lastRemindTime;
	}

	public void setLastRemindTime(Date lastRemindTime) {
		this.lastRemindTime = lastRemindTime;
	}
	
	public Integer getDeveloperSwitch() {
		return developerSwitch;
	}

	public void setDeveloperSwitch(Integer developerSwitch) {
		this.developerSwitch = developerSwitch;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}


	public String getJson() {
		return json;
	}

	public void setJson(String json) {
		this.json = json;
	}
	
	@Override
	public int hashCode() {
		return id.hashCode() * 37 + email.hashCode() * 17;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof DeveloperDO) {
			DeveloperDO developer = (DeveloperDO) obj;
			return (developer.id.equals(id) && developer.email.equals(email));
		}
		return super.equals(obj);
	}
}
